pub struct StreamEchoServer<P: StreamProtocol> { /* private fields */ }Expand description
Generic stream-based echo server that works with any stream protocol
This server can work with any protocol that implements StreamProtocol,
such as TCP, Unix streams, etc.
Examples
Basic server setup and running:
use echosrv::stream::{StreamConfig, StreamEchoServer};
use echosrv::common::EchoServerTrait;
use echosrv::tcp::TcpProtocol;
use std::time::Duration;
#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
let config = StreamConfig {
bind_addr: "127.0.0.1:8080".parse()?,
max_connections: 100,
buffer_size: 1024,
read_timeout: Duration::from_secs(30),
write_timeout: Duration::from_secs(30),
};
let server: StreamEchoServer<TcpProtocol> = StreamEchoServer::new(config);
server.run().await?;
Ok(())
}Implementations
Sourceimpl<P: StreamProtocol> StreamEchoServer<P>
impl<P: StreamProtocol> StreamEchoServer<P>
Sourcepub fn new(config: StreamConfig) -> Self
pub fn new(config: StreamConfig) -> Self
Creates a new stream-based echo server with the given configuration